#!/bin/sh
# (c) The SMDP-Group - http://smdp.sourceforge.net/
#     for any general questions: smdp-devel@lists.sourceforge.net
#     for help on this: fkr@grummel.net
# $Id: build-schema.sh,v 1.20 2001/08/26 23:35:05 fkr Exp $
# building sql-scripts from the dia-files with dia2sql.pl
# see sh build-schema.sh -h for usage.

# just some variables
MYSQL_PATH="./MySQL"
PGSQL_PATH="./PostgreSQL"
MSSQL_PATH="./MS-Sql"
DIA_FILE="./dia/smdp-schema.dia"
ID3_CSV_FILE="./csv/id3.csv"
ID3_SQL_SCRIPT="./general-sql/id3-frames.sql"
FEATURE_CSV_FILE="./csv/feature_types.csv"
FEATURE_SQL_SCRIPT="./general-sql/feature-types.sql"

# if dia2sql.pl is not found here, the script will look in current-directory
# for it. (and there it definitly should be, since it comes with the schemas.
DIA_BIN="./dia2sql.pl"
SQL_GENERATOR="./sql-generator.pl"

while [ $# -gt 0 ]
do
	case "$1" in
		--help|-h)
			usage=t
			break
			;;
		--build-type=*)
			build_type=`echo $1 | sed 's/^--build-type=//'`
			;;
		--db-name=*)
			database_name=`echo $1 | sed 's/^--db-name=//'`
			;;
		--with-dia2sql=*)
			DIA_BIN=`echo $1 | sed 's/^--with-dia2sql=//'`
			;;
	esac
	shift
done

if [ "$usage" ]; then
	echo "Usage: build-schema.sh [option] --build-type=<build-type>"
	echo ""
    echo "Where option is one of:"
    echo "  --with-dia2sql=<path>       where <path> points to the dia2sql.pl perl script"
    echo "  -h | --help                 print this usage statement"
    echo "  --db-name=<db-name>         where <db-name> is the database-name to use"
    echo "                              defaults to 'smdp'"
    echo ""
    echo "Where build-type is one of:"
    echo "  devel           build development schemas"
    echo "  production      build production (release) schemas"
    echo ""
    exit 0
fi

# check for our dia2sql.pl script
if [ ! -e $DIA_BIN ]; then
    if [ -e "/usr/local/bin/dia2sql.pl" ]; then
		$DIA_BIN = "/usr/local/bin/dia2sql.pl"
	else
		echo "dia2sql.pl not found! Adjust path in build-schema.sh"
		echo ""
		exit
	fi
fi

# ok, guess we build development-scripts
if [ "$build_type" == "devel" ]; then
	echo ""
	echo "Starting to build sql-scripts for developement."
	echo ""
	echo ""
	
	args=" --absolute-clean --with-comments "
else
	echo ""
    echo "Starting to build sql-scripts for production."
    echo ""
    echo ""
	args=" "
fi

if [ "$database_name" == "" ]; then
	database_name="smdp"
fi

if [ -e $DIA_FILE ]; then
	echo "building sql-script for mysql!"
    $DIA_BIN --mysql --with-create ${args} --database=${database_name} --input=mysql $DIA_FILE $MYSQL_PATH/smdp-schema.sql
    echo "building sql-script for pgsql!"
    $DIA_BIN --postgresql --convert --with-create ${args} --database=${database_name} --input=mysql $DIA_FILE $PGSQL_PATH/smdp-schema.sql
    echo "building sql-script for ms-sql!"
    $DIA_BIN --mssql --convert --with-html-output --with-create ${args} --database=${database_name} --input=mysql $DIA_FILE $MSSQL_PATH/smdp-schema.sql
fi

if [ -e $ID3_CSV_FILE -a -e $SQL_GENERATOR ]; then
	echo ""
	echo "Building general-sql-file for id3-frames!" 
	$SQL_GENERATOR --task=id3 ${ID3_CSV_FILE} ${ID3_SQL_SCRIPT}
fi

if [ -e $FEATURE_CSV_FILE -a -e $SQL_GENERATOR ]; then
    echo ""
	echo "Building general-sql-file for feature-types!"
	$SQL_GENERATOR --task=feature_type ${FEATURE_CSV_FILE} ${FEATURE_SQL_SCRIPT}
fi

echo ""
echo ""
